#!/bin/bash
if [[ $OSTYPE != "darwin"* ]]; then
    echo "This script is only supported on macOS"
    exit 1
fi

cd "$(dirname "$0")" || exit 1

# export DRIVER_NAME="ESTKme-RED"
REDCTL="$PWD/bin/redctl.darwin"

if [[ ! -f $REDCTL ]]; then
    echo "redctl not found at $REDCTL"
    exit 1
fi

function redctl() {
    "$REDCTL" "$@"
}

function version_ge() {
    test "$(echo -e "$1\n$2" | sort -rV | head -n 1)" == "$1"
}

LABEL="ESTKme-RED"
PRODUCT="ESTKme-RED"
FIRMWARE="$PWD/estkme-red.fwupd"
VOLUME="/Volumes/$LABEL"

CUR_VERSION=""
OLD_VERSION=""
NEW_VERSION="$(cat VERSION)"

if [[ ! -d $VOLUME ]]; then
    OLD_VERSION="$(redctl ver)"
    if [[ -z $OLD_VERSION ]]; then
        echo "Please connect $PRODUCT to computer"
        exit 1
    elif [[ $OLD_VERSION == "0.0.0" ]]; then
        echo "REQUIRE USE short-circuit update firmware"
        exit 2
    elif version_ge "$OLD_VERSION" "$NEW_VERSION"; then
        echo "$PRODUCT is already up-to-date ($NEW_VERSION)"
        exit 3
    fi
fi

if [[ -n $OLD_VERSION ]]; then
    echo "Old firmware version: $OLD_VERSION"
fi
echo "New firmware version: $NEW_VERSION"

if [[ ! -d $VOLUME ]]; then
    echo "Enter $PRODUCT DFU mode"

    redctl dfu
fi

while [[ ! -d $VOLUME ]]; do
    sleep 1
done

echo "Copy firmware to $VOLUME"
cp -v "$FIRMWARE" "$VOLUME"

echo "Unmount $VOLUME"
diskutil unmountDisk "$VOLUME"

echo -e "\033[0;31mPlease re-plug $PRODUCT to continue\033[0m"

while [[ -z $CUR_VERSION ]]; do
    sleep 1
    CUR_VERSION="$(redctl ver 2>/dev/null)"
done

if [[ $NEW_VERSION == "$CUR_VERSION" ]]; then
    echo -e "\033[0;32mFirmware updated successfully ($CUR_VERSION)\033[0m"
else
    echo -e "\033[0;31mFirmware update failed ($CUR_VERSION)\033[0m"
fi
